@@ -8,11 +8,15 @@ use Config::CmdRC qw/.from_unixtimerc/;
 use Exporter 'import';
 our @EXPORT = qw/from_unixtime/;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 our $MAYBE_UNIXTIME = join '|', (
     'created_(?:at|on)',
     'updated_(?:at|on)',
+    'released_(?:at|on)',
+    'closed_(?:at|on)',
+    'published_(?:at|on)',
+    'expired_(?:at|on)',
     'date',
     'unixtime',
     '_time',
@@ -55,8 +59,8 @@ sub _main {
 sub _may_replace {
     my ($line, $config) = @_;
 
-    if ($line =~ m!(?:$MAYBE_UNIXTIME)[^\d]*(\d+)!
-                || ($config->{_re} && $line =~ m!(?:$config->{_re})[^\d]*(\d+)!)
+    if ($line =~ m!(?:$MAYBE_UNIXTIME).*[^\d](\d+)!
+                || ($config->{_re} && $line =~ m!(?:$config->{_re}).*[^\d](\d+)!)
                 || $line =~ m!^[\s\t\r\n]*(\d+)[\s\t\r\n]*$!
     ) {
         return $1;
@@ -80,6 +84,10 @@ sub _replace_unixtime {
         return;
     }
 
+    if ($config->{'min-time'} && $maybe_unixtime < $config->{'min-time'}) {
+        return;
+    }
+
     my $date = strftime($config->{format}, localtime($maybe_unixtime));
     my $replaced_unixtime = sprintf(
         "%s%s%s%s",
@@ -118,6 +126,7 @@ sub _get_options {
         'end-bracket=s'   => \$config->{'end-bracket'},
         're=s@'           => \$config->{re},
         'no-re=s@'        => \$config->{'no-re'},
+        'min-time=i'      => \$config->{'min-time'},
         'h|help' => sub {
             _show_usage(1);
         },
